<?php
/**
 * Theme sprecific functions and definitions
 */


/* Theme setup section
------------------------------------------------------------------- */

// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) $content_width = 1170; /* pixels */

// Add theme specific actions and filters
// Attention! Function were add theme specific actions and filters handlers must have priority 1
if ( !function_exists( 'jarvis_theme_setup' ) ) {
	add_action( 'jarvis_action_before_init_theme', 'jarvis_theme_setup', 1 );
	function jarvis_theme_setup() {

		// Add default posts and comments RSS feed links to head
		add_theme_support( 'automatic-feed-links' );

		// Enable support for Post Thumbnails
		add_theme_support( 'post-thumbnails' );

		// Custom header setup
		add_theme_support( 'custom-header', array('header-text'=>false));

		// Custom backgrounds setup
		add_theme_support( 'custom-background');

		// Supported posts formats
		add_theme_support( 'post-formats', array('gallery', 'video', 'audio', 'link', 'quote', 'image', 'status', 'aside', 'chat') );

		// Autogenerate title tag
		add_theme_support('title-tag');

		// Add user menu
		add_theme_support('nav-menus');

		// WooCommerce Support
		add_theme_support( 'woocommerce' );

		// Add wide and full blocks support
		add_theme_support( 'align-wide' );

		// Register theme menus
		add_filter( 'jarvis_filter_add_theme_menus',		'jarvis_add_theme_menus' );

		// Register theme sidebars
		add_filter( 'jarvis_filter_add_theme_sidebars',	'jarvis_add_theme_sidebars' );

		// Set options for importer
		add_filter( 'jarvis_filter_importer_options',		'jarvis_set_importer_options' );

		add_filter( 'comment_form_fields', 'jarvis_comment_form_agree', 11 );

		// Set list of the theme required plugins
		jarvis_storage_set('required_plugins', array(
			'essgrids',
			'instagram-feed',
			'revslider',
			'tribe_events',
			'trx_utils',
			'visual_composer',
			'woocommerce',
			'contact_form_7',
			'trx_updater',
			'elegro-payment',
			'date-time-picker'
            )
		);


        // Set list of the theme required custom fonts from folder /css/font-faces
        // Attention! Font's folder must have name equal to the font's name
        jarvis_storage_set('required_custom_fonts', array(
            'Amadeus'
            )
        );

    }
}

// Add page meta to the head
if (!function_exists('jarvis_head_add_page_meta')) {
    add_action('wp_head', 'jarvis_head_add_page_meta', 1);
    function jarvis_head_add_page_meta() {
        $theme_skin = sanitize_file_name(jarvis_get_custom_option('theme_skin'));
        ?>
        <meta charset="<?php bloginfo( 'charset' ); ?>" />
        <meta name="viewport" content="width=device-width, initial-scale=1<?php if (jarvis_get_theme_option('responsive_layouts')=='yes') echo ', maximum-scale=1'; ?>">
        <meta name="format-detection" content="telephone=no">
        <link rel="profile" href="//gmpg.org/xfn/11" />
        <link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />

        <?php
    }
}

// Add/Remove theme nav menus
if ( !function_exists( 'jarvis_add_theme_menus' ) ) {
	
	function jarvis_add_theme_menus($menus) {
		return $menus;
	}
}


// Add theme specific widgetized areas
if ( !function_exists( 'jarvis_add_theme_sidebars' ) ) {
	
	function jarvis_add_theme_sidebars($sidebars=array()) {
		if (is_array($sidebars)) {
			$theme_sidebars = array(
				'sidebar_main'		=> esc_html__( 'Main Sidebar', 'jarvis' ),
				'sidebar_footer'	=> esc_html__( 'Footer Sidebar', 'jarvis' )
			);
			if (function_exists('jarvis_exists_woocommerce') && jarvis_exists_woocommerce()) {
				$theme_sidebars['sidebar_cart']  = esc_html__( 'WooCommerce Cart Sidebar', 'jarvis' );
			}
			$sidebars = array_merge($theme_sidebars, $sidebars);
		}
		return $sidebars;
	}
}

//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( ! function_exists( 'jarvis_importer_set_options' ) ) {
    add_filter( 'trx_utils_filter_importer_options', 'jarvis_importer_set_options', 9 );
    function jarvis_importer_set_options( $options=array() ) {
        if ( is_array( $options ) ) {
            // Save or not installer's messages to the log-file
            $options['debug'] = false;
            // Prepare demo data

                $options['demo_url'] = esc_url( jarvis_get_protocol().'://demofiles.ancorathemes.com/jarvis/' ); // Demo-site domain


            // Required plugins
            $options['required_plugins'] =  array(
                'essential-grid',
                'revslider',
                'trx_utils',
                'js_composer',
                'woocommerce',
                'contact-form-7',
                'trx_updater',
                'instagram-feed',
                'instagram_widget',
                'the-events-calendar',
                'content_timeline',
                'contact-form-7',
                'date-time-picker'

            );

            $options['theme_slug'] = 'jarvis';

            // Set number of thumbnails to regenerate when its imported (if demo data was zipped without cropped images)
            // Set 0 to prevent regenerate thumbnails (if demo data archive is already contain cropped images)
            $options['regenerate_thumbnails'] = 3;
            // Default demo
            $options['files']['default']['title'] = esc_html__( 'Jarvis Demo', 'jarvis' );
            $options['files']['default']['domain_dev'] = esc_url( jarvis_get_protocol().'://jarvis.dv.ancorathemes.com'); // Developers domain
            $options['files']['default']['domain_demo']= esc_url( jarvis_get_protocol().'://jarvis.ancorathemes.com'); // Demo-site domain

        }
        return $options;
    }
}





/*+ Special the image size for events */
add_image_size('jarvis-single-event', 380, 470, true);


//*+ Add custom body class to the head
add_filter( 'body_class', 'jarvis_body_class' );
function jarvis_body_class( $classes ) {

    $theme_skin = sanitize_file_name(jarvis_get_custom_option('theme_skin'));
    $blog_style = jarvis_get_custom_option(is_singular() && !jarvis_storage_get('blog_streampage') ? 'single_style' : 'blog_style');
    $body_style  = jarvis_get_custom_option('body_style');
    $article_style = jarvis_get_custom_option('article_style');
    $top_panel_position = jarvis_get_custom_option('top_panel_position');
    $need_collapse_menu = jarvis_get_custom_option('need_collapse_menu');
    $video_bg_show  = jarvis_get_custom_option('show_video_bg')=='yes' && (jarvis_get_custom_option('video_bg_youtube_code')!='' || jarvis_get_custom_option('video_bg_url')!='');

    $classes[] .= 'jarvis_body body_style_' . esc_attr($body_style)
    		. ' body_' . (jarvis_get_custom_option('body_filled')=='yes' ? 'filled' : 'transparent')
    		. ' theme_skin_' . esc_attr($theme_skin)
    		. ' article_style_' . esc_attr($article_style)
    		. ' layout_' . esc_attr($blog_style)
    		. ' template_' . esc_attr(jarvis_get_template_name($blog_style))
            . (!jarvis_param_is_off($need_collapse_menu) ? ' need_collapse_menu ' : '')
            . (!jarvis_param_is_off($top_panel_position) ? ' top_panel_show top_panel_' . esc_attr($top_panel_position) : 'top_panel_hide')
    		. ' ' . esc_attr(jarvis_get_sidebar_class())
    		. ($video_bg_show ? ' video_bg_show' : '')
    		. (jarvis_get_theme_option('page_preloader')!='' ? ' preloader' : '')
			. (!function_exists('trx_utils_sc_init') ? ' trx_utils_absent' : '');
    return $classes;
}

// Add theme required plugins
if ( !function_exists( 'jarvis_add_trx_utils' ) ) {
    add_filter( 'trx_utils_active', 'jarvis_add_trx_utils' );
    function jarvis_add_trx_utils($enable=true) {
        return true;
    }
}


/**
 * Fire the wp_body_open action.
 *
 * Added for backwards compatibility to support pre 5.2.0 WordPress versions.
 */
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        /**
         * Triggered after the opening <body> tag.
         */
        do_action('wp_body_open');
    }
}

if ( ! function_exists( 'jarvis_single_comments_field' ) ) {
	function jarvis_single_comments_field( $args ) {
		 $path_height = 'path' == $args['form_style']
			  ? ( 'text' == $args['field_type'] ? 75 : 190 )
			  : 0;
		 $html = '<div class="comments_field comments_' . esc_attr( $args['field_name'] ) . '">'
			  . '<span class="sc_form_field_wrap">';
		 if ( 'text' == $args['field_type'] ) {
			  $html .= '<input id="' . esc_attr( $args['field_name'] ) . '" name="' . esc_attr( $args['field_name'] ) . '" type="text"' . ( 'default' == $args['form_style'] ? ' placeholder="' . esc_attr( $args['field_placeholder'] ) . ( $args['field_req'] ? ' *' : '' ) . '"' : '' ) . ' value="' . esc_attr( $args['field_value'] ) . '"' . ( $args['field_req'] ? ' aria-required="true"' : '' ) . ' />';
		 } elseif ( 'checkbox' == $args['field_type'] ) {
			  $html .= '<input id="' . esc_attr( $args['field_name'] ) . '" name="' . esc_attr( $args['field_name'] ) . '" type="checkbox" value="' . esc_attr( $args['field_value'] ) . '"' . ( $args['field_req'] ? ' aria-required="true"' : '' ) . ' />'
					. ' <label for="' . esc_attr( $args['field_name'] ) . '" class="' . esc_attr( $args['field_req'] ? 'required' : 'optional' ) . '">' . wp_kses( $args['field_title'], 'ipharm_kses_content' ) . '</label>';
		 } else {
			  $html .= '<textarea id="' . esc_attr( $args['field_name'] ) . '" name="' . esc_attr( $args['field_name'] ) . '"' . ( 'default' == $args['form_style'] ? ' placeholder="' . esc_attr( $args['field_placeholder'] ) . ( $args['field_req'] ? ' *' : '' ) . '"' : '' ) . ( $args['field_req'] ? ' aria-required="true"' : '' ) . '></textarea>';
		 }
		 if ( 'default' != $args['form_style'] && in_array( $args['field_type'], array( 'text', 'textarea' ) ) ) {
			  $html .= '<span class="sc_form_field_hover">'
					. ( 'path' == $args['form_style']
						 ? '<svg class="sc_form_field_graphic" preserveAspectRatio="none" viewBox="0 0 520 ' . intval( $path_height ) . '" height="100%" width="100%"><path d="m0,0l520,0l0,' . intval( $path_height ) . 'l-520,0l0,-' . intval( $path_height ) . 'z"></svg>'
						 : ''
					)
					. ( 'iconed' == $args['form_style']
						 ? '<i class="sc_form_field_icon ' . esc_attr( $args['field_icon'] ) . '"></i>'
						 : ''
					)
					. '<span class="sc_form_field_content" data-content="' . esc_attr( $args['field_title'] ) . '">' . wp_kses( $args['field_title'], 'ipharm_kses_content' ) . '</span>'
					. '</span>';
		 }
		 $html .= '</span></div>';
		 return $html;
	}
}

// Add checkbox with "I agree ..."
if ( ! function_exists( 'jarvis_comment_form_agree' ) ) {
	function jarvis_comment_form_agree( $comment_fields ) {
		 $privacy_text = jarvis_get_privacy_text();
		 if ( ! empty( $privacy_text )
				&& ( ! function_exists( 'jarvis_exists_gdpr_framework' ) || ! jarvis_exists_gdpr_framework() )
				&& ( ! function_exists( 'jarvis_exists_wp_gdpr_compliance' ) || ! jarvis_exists_wp_gdpr_compliance() )
		 ) {
			  $comment_fields['i_agree_privacy_policy'] = jarvis_single_comments_field(
					array(
						 'form_style'        => 'default',
						 'field_type'        => 'checkbox',
						 'field_req'         => '',
						 'field_icon'        => '',
						 'field_value'       => '1',
						 'field_name'        => 'i_agree_privacy_policy',
						 'field_title'       => $privacy_text,
					)
			  );
		 }
		 return $comment_fields;
	}
}

/* Include framework core files
------------------------------------------------------------------- */
// If now is WP Heartbeat call - skip loading theme core files
	require_once get_template_directory().'/fw/loader.php';
?>