<?php
/* Revolution Slider support functions
------------------------------------------------------------------------------- */

// Theme init
if (!function_exists('jarvis_revslider_theme_setup')) {
	add_action( 'jarvis_action_before_init_theme', 'jarvis_revslider_theme_setup', 1 );
	function jarvis_revslider_theme_setup() {
		if (jarvis_exists_revslider()) {
			add_filter( 'jarvis_filter_list_sliders',					'jarvis_revslider_list_sliders' );
			add_filter( 'jarvis_filter_shortcodes_params',			    'jarvis_revslider_shortcodes_params' );
			add_filter( 'jarvis_filter_theme_options_params',			'jarvis_revslider_theme_options_params' );
		}
		if (is_admin()) {
			add_filter( 'jarvis_filter_required_plugins',				'jarvis_revslider_required_plugins' );
		}
	}
}

if ( !function_exists( 'jarvis_revslider_settings_theme_setup2' ) ) {
	add_action( 'jarvis_action_before_init_theme', 'jarvis_revslider_settings_theme_setup2', 3 );
	function jarvis_revslider_settings_theme_setup2() {
		if (jarvis_exists_revslider()) {

			// Add Revslider specific options in the Theme Options
			jarvis_storage_set_array_after('options', 'slider_engine', "slider_alias", array(
				"title" => esc_html__('Revolution Slider: Select slider',  'jarvis'),
				"desc" => wp_kses_data( __("Select slider to show (if engine=revo in the field above)", 'jarvis') ),
				"override" => "category,services_group,page",
				"dependency" => array(
					'show_slider' => array('yes'),
					'slider_engine' => array('revo')
				),
				"std" => "",
				"options" => jarvis_get_options_param('list_revo_sliders'),
				"type" => "select"
				)
			);

		}
	}
}

// Check if RevSlider installed and activated
if ( !function_exists( 'jarvis_exists_revslider' ) ) {
	function jarvis_exists_revslider() {
		return function_exists('rev_slider_shortcode');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'jarvis_revslider_required_plugins' ) ) {
	
	function jarvis_revslider_required_plugins($list=array()) {
        if (in_array('revslider', jarvis_storage_get('required_plugins'))) {
            $path = jarvis_get_file_dir('plugins/install/revslider.zip');
            if (file_exists($path)) {
                $list[] = array(
                    'name' 		=> esc_html__('Revolution Slider', 'jarvis'),
                    'slug' 		=> 'revslider',
                    'source'	=> $path,
                    'version'   => '6.6.20',
                    'required' 	=> false
                );
            }
        }
		return $list;
	}
}

// Lists
//------------------------------------------------------------------------

// Add RevSlider in the sliders list, prepended inherit (if need)
if ( !function_exists( 'jarvis_revslider_list_sliders' ) ) {
	
	function jarvis_revslider_list_sliders($list=array()) {
		$list["revo"] = esc_html__("Layer slider (Revolution)", 'jarvis');
		return $list;
	}
}

// Return Revo Sliders list, prepended inherit (if need)
if ( !function_exists( 'jarvis_get_list_revo_sliders' ) ) {
	function jarvis_get_list_revo_sliders($prepend_inherit=false) {
		if (($list = jarvis_storage_get('list_revo_sliders'))=='') {
			$list = array();
			if (jarvis_exists_revslider()) {
				global $wpdb;
				$rows = $wpdb->get_results( "SELECT alias, title FROM " . esc_sql($wpdb->prefix) . "revslider_sliders" );
				if (is_array($rows) && count($rows) > 0) {
					foreach ($rows as $row) {
						$list[$row->alias] = $row->title;
					}
				}
			}
			$list = apply_filters('jarvis_filter_list_revo_sliders', $list);
			if (jarvis_get_theme_setting('use_list_cache')) jarvis_storage_set('list_revo_sliders', $list);
		}
		return $prepend_inherit ? jarvis_array_merge(array('inherit' => esc_html__("Inherit", 'jarvis')), $list) : $list;
	}
}

// Add RevSlider in the shortcodes params
if ( !function_exists( 'jarvis_revslider_shortcodes_params' ) ) {
	
	function jarvis_revslider_shortcodes_params($list=array()) {
		$list["revo_sliders"] = jarvis_get_list_revo_sliders();
		return $list;
	}
}

// Add RevSlider in the Theme Options params
if ( !function_exists( 'jarvis_revslider_theme_options_params' ) ) {
	
	function jarvis_revslider_theme_options_params($list=array()) {
		$list["list_revo_sliders"] = array('$jarvis_get_list_revo_sliders' => '');
		return $list;
	}
}
?>