<?php

// Check if shortcodes settings are now used
if ( !function_exists( 'jarvis_shortcodes_is_used' ) ) {
	function jarvis_shortcodes_is_used() {
		return jarvis_options_is_used() 															// All modes when Theme Options are used
			|| (is_admin() && isset($_POST['action']) 
					&& in_array($_POST['action'], array('vc_edit_form', 'wpb_show_edit_form')))		// AJAX query when save post/page
			|| (is_admin() && jarvis_strpos($_SERVER['REQUEST_URI'], 'vc-roles')!==false)			// VC Role Manager
			|| (function_exists('jarvis_vc_is_frontend') && jarvis_vc_is_frontend());			// VC Frontend editor mode
	}
}

// Width and height params
if ( !function_exists( 'jarvis_shortcodes_width' ) ) {
	function jarvis_shortcodes_width($w="") {
		return array(
			"title" => esc_html__("Width", "jarvis"),
			"divider" => true,
			"value" => $w,
			"type" => "text"
		);
	}
}
if ( !function_exists( 'jarvis_shortcodes_height' ) ) {
	function jarvis_shortcodes_height($h='') {
		return array(
			"title" => esc_html__("Height", "jarvis"),
			"desc" => wp_kses( __("Width (in pixels or percent) and height (only in pixels) of element", "jarvis"), jarvis_storage_get('allowed_tags') ),
			"value" => $h,
			"type" => "text"
		);
	}
}

// Return sc_param value
if ( !function_exists( 'jarvis_get_sc_param' ) ) {
	function jarvis_get_sc_param($prm) {
		return jarvis_storage_get_array('sc_params', $prm);
	}
}

// Set sc_param value
if ( !function_exists( 'jarvis_set_sc_param' ) ) {
	function jarvis_set_sc_param($prm, $val) {
		jarvis_storage_set_array('sc_params', $prm, $val);
	}
}

// Add sc settings in the sc list
if ( !function_exists( 'jarvis_sc_map' ) ) {
	function jarvis_sc_map($sc_name, $sc_settings) {
		jarvis_storage_set_array('shortcodes', $sc_name, $sc_settings);
	}
}

// Add sc settings in the sc list after the key
if ( !function_exists( 'jarvis_sc_map_after' ) ) {
	function jarvis_sc_map_after($after, $sc_name, $sc_settings='') {
		jarvis_storage_set_array_after('shortcodes', $after, $sc_name, $sc_settings);
	}
}

// Add sc settings in the sc list before the key
if ( !function_exists( 'jarvis_sc_map_before' ) ) {
	function jarvis_sc_map_before($before, $sc_name, $sc_settings='') {
		jarvis_storage_set_array_before('shortcodes', $before, $sc_name, $sc_settings);
	}
}



/* Theme setup section
-------------------------------------------------------------------- */

if ( !function_exists( 'jarvis_shortcodes_settings_theme_setup' ) ) {
//	if ( jarvis_vc_is_frontend() )
	if ( (isset($_GET['vc_editable']) && $_GET['vc_editable']=='true') || (isset($_GET['vc_action']) && $_GET['vc_action']=='vc_inline') )
		add_action( 'jarvis_action_before_init_theme', 'jarvis_shortcodes_settings_theme_setup', 20 );
	else
		add_action( 'jarvis_action_after_init_theme', 'jarvis_shortcodes_settings_theme_setup' );
	function jarvis_shortcodes_settings_theme_setup() {
		if (jarvis_shortcodes_is_used()) {

			// Sort templates alphabetically
			$tmp = jarvis_storage_get('registered_templates');
			ksort($tmp);
			jarvis_storage_set('registered_templates', $tmp);

			// Prepare arrays 
			jarvis_storage_set('sc_params', array(
			
				// Current element id
				'id' => array(
					"title" => esc_html__("Element ID", "jarvis"),
					"desc" => wp_kses( __("ID for current element", "jarvis"), jarvis_storage_get('allowed_tags') ),
					"divider" => true,
					"value" => "",
					"type" => "text"
				),
			
				// Current element class
				'class' => array(
					"title" => esc_html__("Element CSS class", "jarvis"),
					"desc" => wp_kses( __("CSS class for current element (optional)", "jarvis"), jarvis_storage_get('allowed_tags') ),
					"value" => "",
					"type" => "text"
				),
			
				// Current element style
				'css' => array(
					"title" => esc_html__("CSS styles", "jarvis"),
					"desc" => wp_kses( __("Any additional CSS rules (if need)", "jarvis"), jarvis_storage_get('allowed_tags') ),
					"value" => "",
					"type" => "text"
				),
			
			
				// Switcher choises
				'list_styles' => array(
					'ul'	=> esc_html__('Unordered', 'trx_utils'),
					'ol'	=> esc_html__('Ordered', 'trx_utils'),
					'iconed'=> esc_html__('Iconed', 'trx_utils')
				),

				'yes_no'	=> jarvis_get_list_yesno(),
				'on_off'	=> jarvis_get_list_onoff(),
				'dir' 		=> jarvis_get_list_directions(),
				'align'		=> jarvis_get_list_alignments(),
				'float'		=> jarvis_get_list_floats(),
				'hpos'		=> jarvis_get_list_hpos(),
				'show_hide'	=> jarvis_get_list_showhide(),
				'sorting' 	=> jarvis_get_list_sortings(),
				'ordering' 	=> jarvis_get_list_orderings(),
				'shapes'	=> jarvis_get_list_shapes(),
				'sizes'		=> jarvis_get_list_sizes(),
				'sliders'	=> jarvis_get_list_sliders(),
                    'categories'=> is_admin() && jarvis_get_value_gp('action')=='vc_edit_form' && substr(jarvis_get_value_gp('tag'), 0, 4)=='trx_' && isset($_POST['params']['post_type']) && $_POST['params']['post_type']!='post'
                        ? jarvis_get_list_terms(false, jarvis_get_taxonomy_categories_by_post_type($_POST['params']['post_type']))
                        : jarvis_get_list_categories(),
				'columns'	=> jarvis_get_list_columns(),
				'images'	=> array_merge(array('none'=>"none"), jarvis_get_list_images("images/icons", "png")),
				'icons'		=> array_merge(array("inherit", "none"), jarvis_get_list_icons()),
				'locations'	=> jarvis_get_list_dedicated_locations(),
				'filters'	=> jarvis_get_list_portfolio_filters(),
				'formats'	=> jarvis_get_list_post_formats_filters(),
				'hovers'	=> jarvis_get_list_hovers(true),
				'hovers_dir'=> jarvis_get_list_hovers_directions(true),
				'schemes'	=> jarvis_get_list_color_schemes(true),
				'animations'		=> jarvis_get_list_animations_in(),
				'margins' 			=> jarvis_get_list_margins(true),
				'blogger_styles'	=> jarvis_get_list_templates_blogger(),
				'forms'				=> jarvis_get_list_templates_forms(),
				'posts_types'		=> jarvis_get_list_posts_types(),
				'googlemap_styles'	=> jarvis_get_list_googlemap_styles(),
				'field_types'		=> jarvis_get_list_field_types(),
				'label_positions'	=> jarvis_get_list_label_positions()
				)
			);

			// Common params
			jarvis_set_sc_param('animation', array(
				"title" => esc_html__("Animation",  'trx_utils'),
				"desc" => wp_kses( __('Select animation while object enter in the visible area of page',  'trx_utils'), jarvis_storage_get('allowed_tags') ),
				"value" => "none",
				"type" => "select",
				"options" => jarvis_get_sc_param('animations')
				)
			);
			jarvis_set_sc_param('top', array(
				"title" => esc_html__("Top margin",  'trx_utils'),
				"divider" => true,
				"value" => "inherit",
				"type" => "select",
				"options" => jarvis_get_sc_param('margins')
				)
			);
			jarvis_set_sc_param('bottom', array(
				"title" => esc_html__("Bottom margin",  'trx_utils'),
				"value" => "inherit",
				"type" => "select",
				"options" => jarvis_get_sc_param('margins')
				)
			);
			jarvis_set_sc_param('left', array(
				"title" => esc_html__("Left margin",  'trx_utils'),
				"value" => "inherit",
				"type" => "select",
				"options" => jarvis_get_sc_param('margins')
				)
			);
			jarvis_set_sc_param('right', array(
				"title" => esc_html__("Right margin",  'trx_utils'),
				"desc" => wp_kses( __("Margins around this shortcode", "jarvis"), jarvis_storage_get('allowed_tags') ),
				"value" => "inherit",
				"type" => "select",
				"options" => jarvis_get_sc_param('margins')
				)
			);

			jarvis_storage_set('sc_params', apply_filters('jarvis_filter_shortcodes_params', jarvis_storage_get('sc_params')));

			// Shortcodes list
			//------------------------------------------------------------------
			jarvis_storage_set('shortcodes', array());
			
			// Register shortcodes
			do_action('jarvis_action_shortcodes_list');

			// Sort shortcodes list
			$tmp = jarvis_storage_get('shortcodes');
			uasort($tmp, function($a, $b) {
				return strcmp($a['title'], $b['title']);
			});
			jarvis_storage_set('shortcodes', $tmp);
		}
	}
}
?>